<?php
require_once( "config.class.php" );
class wecker extends config {
	private $cfg_vars = array();
	private $alarmer_status = NULL;

	function __construct() {
		parent::__construct();
		/**	Alle Variablen die fuer die Wecker-Konfiguration
			notwendig sind aus dem config-File auslesen.
		*/
		$this->cfg_vars = $this->get_cfg_vars( $this->config_dir."/config", array(
			"ALARM",
			"ALARM_STREAM",
			"ALARM_TEMP_FORECAST",
			"ALARM_TEMP_AKTUELL",
			"ALARM_VOLUME",
			"ALARM_TIME_MO",
			"ALARM_TIME_DI",
			"ALARM_TIME_MI",
			"ALARM_TIME_DO",
			"ALARM_TIME_FR",
			"ALARM_TIME_SA",
			"ALARM_TIME_SO"
		) );
	}

	public function get_weekplan() {
		$weekplan = array();
		$weekplan["MO"] = explode( ":", $this->cfg_vars["ALARM_TIME_MO"] );
		$weekplan["DI"] = explode( ":", $this->cfg_vars["ALARM_TIME_DI"] );
		$weekplan["MI"] = explode( ":", $this->cfg_vars["ALARM_TIME_MI"] );
		$weekplan["DO"] = explode( ":", $this->cfg_vars["ALARM_TIME_DO"] );
		$weekplan["FR"] = explode( ":", $this->cfg_vars["ALARM_TIME_FR"] );
		$weekplan["SA"] = explode( ":", $this->cfg_vars["ALARM_TIME_SA"] );
		$weekplan["SO"] = explode( ":", $this->cfg_vars["ALARM_TIME_SO"] );
		return( $weekplan );
	}

	public function set_weekplan( $timeofday ) {
		$regex = array();
		$value = array();
		foreach( $timeofday as $day => $time ) {
		/**	Arrays erstellen mit den zu suchenden Variablen
			und den zu ersetzenden Werten.
		*/
			array_push( $regex, "/ALARM_TIME_$day=.*/i" );
			if( $time == ":" ) {
				// Wenn keine Zeit angegeben, dann leer lassen
				$time = "";
			}
			array_push( $value, "ALARM_TIME_$day=$time" );
			$this->cfg_vars[ "ALARM_TIME_$day" ] = $time;
		}
		return( $this->replace_file_regex( $this->config_dir."/config", $regex, $value ) );
	}

	public function get_atq() {
		$output = explode( "\n", trim( shell_exec( "/usr/bin/atq" ) ) );
		$atjobs = array();
		foreach( $output as $job ) {
			if( $job != "" ) {
				$key = array_push( $atjobs, explode( " ", str_replace( "\t", " ", $job ) ) );
				unset( $atjobs[ $key - 1 ][3] );
			}
		}

		return( $atjobs );
	}

	public function new_at( $time, $date, $command ) {
		if( preg_match( "/[0-2][0-9]:[0-5][0-9]/i", $time ) AND preg_match( "/[0-3][0-9]\.[0-1][0-9]\.20[0-9]{2}/i", $date ) AND is_string( $command ) ) {
			/**	Format fuer Uhrzeit: mm:hh
				Format fuer Datum:   DD:MM:YYYY
			*/

			// Wenn localtime noch nicht korrekt ist, vorher ueberschreiben
			if( is_link( "/etc/localtime" ) ) {
				unlink( "/etc/localtime" );
				copy( "/mnt/mediadistro/etc/localtime", "/etc/localtime" );
			}

			// Ueberpruefen ob der geplante Zeitpunkt schon vorbei ist
			if( strtotime( "$time $date" ) - strtotime( "now" ) < 0 ) {
				$this->addError( "Der angegebene Zeitpunkt ist bereits verstrichen!" );
				return( false );
			}

			// echo mit pipe, damit man auch argumente fuer den Befehl uebergeben kann
			exec( "echo \"$command\" | /usr/bin/at $time $date" );
			return( true );
		} else {
			$this->addError( "Das Zeit/Datums-Format ist ung&uuml;ltig!" );
			return( false );
		}
	}

	public function del_at( $id ) {
		if( is_int( $id ) ) {
			exec( "/usr/bin/atrm $id" );
			return( true );
		} else {
			$this->addError( "Die angegebene ID ist ung&uuml;ltig!" );
			return( false );
		}
	}

	public function set_alarmer() {
		exec( "/usr/bin/set_alarmer" );
		return( true );
	}

	public function get_alarmer( $renew = false ) {
		// In der Regel reicht es einmalig den Staus mit
		// atq abzufragen. Mit renew = true laesst er
		// sich aber auch ein zweites Mal abfragen.
		if( $renew OR $this->alarmer_status == NULL ) {
			if( shell_exec( "/usr/bin/atq" ) == "" ) {
				$this->alarmer_status = false;
				return( false );
			} else {
				$this->alarmer_status = true;
				return( true );
			}
		} else {
			return( $this->alarmer_status );
		}
	}

	public function get_configs() {
		return( array(
		"ALARM" => $this->cfg_vars["ALARM"],
		"ALARM_STREAM" => $this->cfg_vars["ALARM_STREAM"],
		"ALARM_TEMP_FORECAST" => $this->cfg_vars["ALARM_TEMP_FORECAST"],
		"ALARM_TEMP_AKTUELL" => $this->cfg_vars["ALARM_TEMP_AKTUELL"],
		"ALARM_VOLUME" => $this->cfg_vars["ALARM_VOLUME"]
		) );
	}

	public function set_alm_config( $values ) {
		$regex = array(
			"/ALARM=.*/i",
			"/ALARM_STREAM=.*/i",
			"/ALARM_VOLUME=.*/i",
			"/ALARM_TEMP_FORECAST=.*/i",
			"/ALARM_TEMP_AKTUELL=.*/i"
		);
		if( $values['alm_temp1'] != "" ) {
			$values['alm_temp1'] = "http://weather.yahoo.com/".$values['alm_temp1'];
		}
		$value = array(
			"ALARM=".$values['alm_sound'],
			"ALARM_STREAM=".$values['alm_stream'],
			"ALARM_VOLUME=".$values['alm_vol'],
			"ALARM_TEMP_FORECAST=\"".$values['alm_temp1']."\"",
			"ALARM_TEMP_AKTUELL=\"".$values['alm_temp2']."\""
		);

		$this->cfg_vars[ "ALARM" ] = $values['alm_sound'];
		$this->cfg_vars[ "ALARM_STREAM" ] = $values['alm_stream'];
		$this->cfg_vars[ "ALARM_TEMP_FORECAST" ] = $values['alm_temp1'];
		$this->cfg_vars[ "ALARM_TEMP_AKTUELL" ] = $values['alm_temp2'];
		$this->cfg_vars[ "ALARM_VOLUME" ] = $values['alm_vol'];

		return( $this->replace_file_regex( $this->config_dir."/config", $regex, $value ) );
	}
}

?>
